Documentation
¶
Index ¶
Constants ¶
const ( GraphQLPOSTURL = "https://poe.com/api/gql_POST" GraphQLRecvURL = "https://poe.com/api/receive_POST" HomeURL = "https://poe.com" SettingsURL = "https://poe.com/api/settings" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChatInputMetadata ¶
type ChatInputMetadata struct {
UseVoiceRecord bool `json:"useVoiceRecord"`
}
type Config ¶
type Config struct {
// Log into Poe on any desktop web browser, then open your browser's developer tools (also known as "inspect") and look for the value of the p-b cookie in the following menus:
// Chromium: Devtools > Application > Cookies > poe.com
// Firefox: Devtools > Storage > Cookies
// Safari: Devtools > Storage > Cookies
Token string
// The device ID to use. If this is not specified, it will be randomly generated and stored on the disk.
DeviceID string
// The headers to use. This defaults to the headers specified in
// poego.Headers
Headers []string
Proxy string // TODO
}
Config poe-go config struct
type Extensions ¶
type Extensions struct {
Hash string `json:"hash"`
}
type GraphQLPostPayload ¶
type GraphQLPostPayload struct {
QueryName string `json:"queryName"`
Variables interface{} `json:"variables"`
Extensions Extensions `json:"extensions"`
}
type SendMessageArgs ¶
type Source ¶
type Source struct {
SourceType SourceType `json:"sourceType"`
ChatInputMetadata ChatInputMetadata `json:"chatInputMetadata"`
}
type SourceType ¶
type SourceType string
SourceTypeChatInput
const SourceTypeChatInput SourceType = "chat_input"
Click to show internal directories.
Click to hide internal directories.